==> dasu_1.0.jar: edu/northwestern/dasu/stats/DownloadStatsDynamic.java <==
/**
 * News Project
 *
 * File:         DownloadStats.java
 * RCS:          $Id: DownloadStatsDynamic.java,v 1.2 2010/05/26 22:18:54 mas939 Exp $
 * Description:  DownloadStats class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 10, 2007 at 1:39:15 PM
 * Language:     Java
 * Package:      edu.northwestern.news.stats
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2007, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.stats;


import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import org.gudy.azureus2.plugins.download.Download;
import org.gudy.azureus2.plugins.download.DownloadManager;
import org.gudy.azureus2.plugins.peers.PeerManager;

import edu.northwestern.dasu.Main;
import edu.northwestern.dasu.util.Util;

/**
 * @author Mario Sanchez &lt;msanchez@u.northwestern.edu&gt;
 *
 * downloadStatDynamic5
 */

public class DownloadStatsDynamic{

	public long downloadId;
	public long timeRecorded;
	public int numPeers;
	public float availability;
	public int completed;
	public int discarded;
	public int downloadRate;
	public int shareRatio;
	public int uploadRate;
	public int numKnownNonSeeds;
	public int numKnownSeeds;
	public int totalNumKnownNonSeeds=-1;
	public int totalNumKnownSeeds=-1;
	public int state;
	public int priority;
	public long downloaded;
	public long uploaded;
	public int position;
	public int numOnoPeers=-1;
	public long hashFails=0;
	public int numRst=0;
	public String downloadName = null;
	public int connectedSeeds=0;
	public int connectedLeechers=0;
	public int numPendingPeers=0;
	
	public DownloadStatsDynamic(Download download, int numRst) {

		downloadId = getId(download);
		timeRecorded = Util.currentGMTTime();
		availability = download.getStats().getAvailability();
		completed = download.getStats().getCompleted();
		discarded = (int) download.getStats().getDiscarded();
		hashFails = download.getStats().getHashFails();
		downloadRate = (int) download.getStats().getDownloadAverage();
		shareRatio = download.getStats().getShareRatio();
		uploadRate = (int) download.getStats().getUploadAverage();
		numKnownNonSeeds = download.getLastAnnounceResult().getNonSeedCount();
		numKnownSeeds = download.getLastAnnounceResult().getSeedCount();
		totalNumKnownNonSeeds = download.getLastScrapeResult().getNonSeedCount();
		totalNumKnownSeeds = download.getLastScrapeResult().getSeedCount();
		state = download.getState();
		priority = download.getIndex();
		position = download.getPosition();
		downloaded = download.getStats().getDownloaded();
		uploaded = download.getStats().getUploaded();
		downloadName = download.getName();
		PeerManager pm = download.getPeerManager();			
		if (pm!=null){
			numPeers = pm.getPeers().length;
			numOnoPeers = -1;
			connectedSeeds =  download.getPeerManager().getStats().getConnectedSeeds();
			connectedLeechers = download.getPeerManager().getStats().getConnectedLeechers();
			numPendingPeers = pm.getPendingPeers().length;
		}
		this.numRst = numRst;
	}

	public DownloadStatsDynamic() {
		timeRecorded = Util.currentGMTTime();
	}

	public boolean contains(String s) {

		if (s.equals("downloadId") || s.equals("timeRecorded") || s.equals("numPeers") ||
				s.equals("availability") || s.equals("completed") || s.equals("discarded") ||
				s.equals("downloadRate")  || s.equals("shareRatio") || s.equals("uploadRate") ||
				s.equals("numKnownNonSeeds") || s.equals("numKnownSeeds") ||
				s.equals("totalNumKnownNonSeeds") || s.equals("totalNumKnownSeeds") ||
				s.equals("state") || s.equals("priority") || s.equals("downloaded") ||
				s.equals("uploaded") || s.equals("position") || s.equals("numOnoPeers") ||
				s.equals("hashFails") || s.equals("connectedSeeds") || s.equals("connectedLeechs") ||
				s.equals("numPendingPeers"))
			return true;
		
		return false;
			
	}

	private int getId(Download d) {
		return Main.getId(d);
	}
		


}

==> dasu_2.02.jar: edu/northwestern/dasu/stats/DownloadStatsDynamic.java <==
/**
 * Dasu Project
 *
 * File:         DownloadStats.java
 * RCS:          $Id: DownloadStatsDynamic.java,v 1.4 2010/10/22 19:51:35 mas939 Exp $
 * Description:  DownloadStats class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 10, 2007 at 1:39:15 PM
 * Language:     Java
 * Package:      edu.northwestern.news.stats
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2007, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.stats;


import org.gudy.azureus2.core3.download.DownloadManager;
import org.gudy.azureus2.plugins.download.Download;
import org.gudy.azureus2.plugins.peers.PeerManager;

import edu.northwestern.dasu.Main;
import edu.northwestern.dasu.util.Util;

/**
 * @author Mario Sanchez &lt;msanchez@u.northwestern.edu&gt;
 *
 * downloadStatDynamic5
 */

public class DownloadStatsDynamic implements Cloneable {

	public long downloadId;
	public long timeRecorded;
	public int numPeers;
	public float availability;
	public int completed;
	public int discarded;
	public int downloadRate;
	public int shareRatio;
	public int uploadRate;
	public int numKnownNonSeeds;
	public int numKnownSeeds;
	public int totalNumKnownNonSeeds=-1;
	public int totalNumKnownSeeds=-1;
	public int state;
	public int priority;
	public long downloaded;
	public long uploaded;
	public int position;
	public long hashFails=0;
	public int numRst=0;
	public String downloadName = null;
	public int connectedSeeds=0;
	public int connectedLeechers=0;
	public int numPendingPeers=0;
	public long swarmPeerSpeed=-1;
	
	public DownloadStatsDynamic(Download download, int numRst) {

		downloadId = getId(download);
		timeRecorded = Util.currentGMTTime();
		availability = download.getStats().getAvailability();
		completed = download.getStats().getCompleted();
		discarded = (int) download.getStats().getDiscarded();
		hashFails = download.getStats().getHashFails();
		downloadRate = (int) download.getStats().getDownloadAverage();
		shareRatio = download.getStats().getShareRatio();
		uploadRate = (int) download.getStats().getUploadAverage();
		numKnownNonSeeds = download.getLastAnnounceResult().getNonSeedCount();
		numKnownSeeds = download.getLastAnnounceResult().getSeedCount();
		totalNumKnownNonSeeds = download.getLastScrapeResult().getNonSeedCount();
		totalNumKnownSeeds = download.getLastScrapeResult().getSeedCount();
		state = download.getState();
		priority = download.getIndex();
		position = download.getPosition();
		downloaded = download.getStats().getDownloaded();
		uploaded = download.getStats().getUploaded();
		downloadName = download.getName();

		for (Object obj : Main.getGlobalManager().getDownloadManagers()) {
			DownloadManager dm = (DownloadManager) obj;
			if (dm.getDisplayName().equals(download.getName()))
				swarmPeerSpeed = dm.getStats().getTotalAveragePerPeer();
		}
		
		PeerManager pm = download.getPeerManager();	
		if (pm!=null){
			numPeers = pm.getPeers().length;
			connectedSeeds =  download.getPeerManager().getStats().getConnectedSeeds();
			connectedLeechers = download.getPeerManager().getStats().getConnectedLeechers();
			numPendingPeers = pm.getPendingPeers().length;
		}
		this.numRst = numRst;
	}

	public DownloadStatsDynamic() {
		timeRecorded = Util.currentGMTTime();
	}

	public boolean contains(String s) {

		if (s.equals("downloadId") || s.equals("timeRecorded") || s.equals("numPeers") ||
				s.equals("availability") || s.equals("completed") || s.equals("discarded") ||
				s.equals("downloadRate")  || s.equals("shareRatio") || s.equals("uploadRate") ||
				s.equals("numKnownNonSeeds") || s.equals("numKnownSeeds") ||
				s.equals("totalNumKnownNonSeeds") || s.equals("totalNumKnownSeeds") ||
				s.equals("state") || s.equals("priority") || s.equals("downloaded") ||
				s.equals("uploaded") || s.equals("position") || s.equals("numOnoPeers") ||
				s.equals("hashFails") || s.equals("connectedSeeds") || s.equals("connectedLeechs") ||
				s.equals("numPendingPeers"))
			return true;
		
		return false;
			
	}

	private int getId(Download d) {
		return Main.getId(d);
	}
		
    public Object clone() {

      	 try {
                return super.clone();
            }
      	 catch( CloneNotSupportedException e ) {
                return null;
            }
        } 


}
